
from lazyme.fileio import find_file

from lazyme.iterate import per_section, per_chunk, per_window
from lazyme.iterate import zigzag

from lazyme.string import *

from lazyme.wikipedia import iter_paragraph as iter_wiki
